<div class="jumbotron bg-gradient font-white margin-bottom-30">
    <div class="container">
        <div class="col-md-12">
            <h1>Redberry CMS</h1>
            <p class="font-muted">Deliciously simple blog functionality for your Flask app.</p>
        </div>
    </div>
</div>