{% import "redberry/_macros.html" as macros %}

<div class="container">
    <ol class="breadcrumb">
        <li>
            <a href="{{ url_for('redberry.home') }}">
                {{ macros.svg_icon('icon-home') }}
            </a>
        </li>
        <li>
            {{ category.title }}
        </li>
    </ol>
</div>
