{% if render_amp %}

    <!doctype html>

    <html amp>
        <head>
            {% include "redberry/_head.amp.html" %}

            {% block head %}{% endblock %}
        </head>

        <body>
            {% include "redberry/symbol-defs.svg" %}
            {% include "redberry/_flashed_messages.html" %}
            {% block content %}{% endblock %}
        </body>
    </html>

{% else %}
    <!doctype html>

    <html>
        <head>
            {% include "redberry/_head.html" %}

            {{ self.head() }}
        </head>

        <body>
            {% include "redberry/symbol-defs.svg" %}
            {% include "redberry/_flashed_messages.html" %}
            {{ self.content() }}

            <script src="https://ajax.googleapis.com/ajax/libs/jquery/3.1.1/jquery.min.js"></script>
            <script type="text/javascript" src="{{ url_for('redberry.static', filename='js/redberry.js')}}"></script>
            {% block javascript %}{% endblock %}
        </body>
    </html>
{% endif %}
