{% extends "index.html" %}

{% block content %}
<a href="{{ url_for('blog.home') }}">Blog Home</a>
<h3>{{ author.first_name }} {{ author.last_name }} Recent Posts</h3>

{% for post in author.recent_posts %}
<div><a href="{{ url_for('blog.show_post', slug=post.slug) }}">{{ post.title }}</a></div>
{% endfor %}

{% endblock %}