<meta charset="utf-8"/>
<script async src="https://cdn.ampproject.org/v0.js"></script>
<meta http-equiv="X-UA-Compatible" content="IE=edge,chrome=1"/>
<meta name="viewport" content="width=device-width, initial-scale=1, minimum-scale=1, user-scalable=no">

{% block head %}
<title>Redberry CMS - a Flask blog blueprint</title>
{% endblock %}

{% if ".amp" in request.url %}
    {% set canonical = request.url | replace(".amp", "") %}
    <link rel="canonical" href="{{ canonical }}" />
{% endif %}

<style amp-boilerplate>
body{-webkit-animation:-amp-start 8s steps(1,end) 0s 1 normal both;-moz-animation:-amp-start 8s steps(1,end) 0s 1 normal both;-ms-animation:-amp-start 8s steps(1,end) 0s 1 normal both;animation:-amp-start 8s steps(1,end) 0s 1 normal both}@-webkit-keyframes -amp-start{from{visibility:hidden}to{visibility:visible}}@-moz-keyframes -amp-start{from{visibility:hidden}to{visibility:visible}}@-ms-keyframes -amp-start{from{visibility:hidden}to{visibility:visible}}@-o-keyframes -amp-start{from{visibility:hidden}to{visibility:visible}}@keyframes -amp-start{from{visibility:hidden}to{visibility:visible}}
</style>

<noscript>
    <style amp-boilerplate>body{-webkit-animation:none;-moz-animation:none;-ms-animation:none;animation:none}</style>
</noscript>

<link rel="stylesheet" href="https://fonts.googleapis.com/css?family=Dosis">

<style amp-custom>
{% include "redberry/amp.css.html" %}
</style>