svg#svg-definitions { position: absolute; width: 0; height: 0; overflow: hidden; }



html, body, input, textarea {
    color: #8492A6;
    font: 300 16px "Dosis", sans-serif;
    line-height: 1.5em;
    background: #eff2f7;
    -webkit-font-smoothing: antialiased;
    -moz-osx-font-smoothing: grayscale;
    margin: 0;
}

a { color: #337ab7; text-decoration: none; }

h1, h2, h3, h4, h5, h6 {
    color: #3C4858;
    font-weight: 400;
    line-height: 1.1;
}

.row:before, .row:after, .container:before, .container:after { display: table; content: " "; }
.container { width: 90%; margin: auto; }

.row {
    margin-right: -15px;
    margin-left: -15px;
}
    .row:after { clear: both; }

.col-lg-1, .col-lg-10, .col-lg-11, .col-lg-12, .col-lg-2, .col-lg-3, .col-lg-4, .col-lg-5, .col-lg-6, .col-lg-7, .col-lg-8, .col-lg-9, .col-md-1, .col-md-10, .col-md-11, .col-md-12, .col-md-2, .col-md-3, .col-md-4, .col-md-5, .col-md-6, .col-md-7, .col-md-8, .col-md-9, .col-sm-1, .col-sm-10, .col-sm-11, .col-sm-12, .col-sm-2, .col-sm-3, .col-sm-4, .col-sm-5, .col-sm-6, .col-sm-7, .col-sm-8, .col-sm-9, .col-xs-1, .col-xs-10, .col-xs-11, .col-xs-12, .col-xs-2, .col-xs-3, .col-xs-4, .col-xs-5, .col-xs-6, .col-xs-7, .col-xs-8, .col-xs-9 {
    position: relative;
    min-height: 1px;
    padding-right: 15px;
    padding-left: 15px;
}

.label {
    display: inline;
    padding: .2em .6em .3em;
    font-size: 75%;
    font-weight: 700;
    line-height: 1;
    color: #fff;
    text-align: center;
    white-space: nowrap;
    vertical-align: baseline;
    border-radius: .25em;
}
    .label-success { background-color: #5cb85c; }

.btn {
    display: inline-block;
    padding: 6px 12px;
    margin-bottom: 0;
    font-size: 14px;
    font-weight: 400;
    line-height: 1.42857143;
    text-align: center;
    white-space: nowrap;
    vertical-align: middle;
    -ms-touch-action: manipulation;
    touch-action: manipulation;
    cursor: pointer;
    -webkit-user-select: none;
    -moz-user-select: none;
    -ms-user-select: none;
    user-select: none;
    background-image: none;
    border: 1px solid transparent;
    border-radius: 4px;
}
.btn-primary {
    color: #fff;
    background-color: #337ab7;
    border-color: #2e6da4;
}

.btn-group-lg>.btn, .btn-lg {
    padding: 10px 16px;
    font-size: 18px;
    line-height: 1.3333333;
    border-radius: 6px;
}

.icon {
    display: inline-block;
    width: 1em;
    height: 1em;
    stroke-width: 0;
    stroke: #8492A6;
    fill: #8492A6;
    cursor: pointer;
}

.panel {
    margin-bottom: 20px;
    background-color: #fff;
    border: 1px solid transparent;
    border-radius: 4px;
    -webkit-box-shadow: 0 1px 1px rgba(0,0,0,.05);
    box-shadow: 0 1px 1px rgba(0,0,0,.05);
}

.red-post {
    background: #fff;
    min-height: 350px;
    padding: 10px;
    position: relative;
    font-size: 18px;
    line-height: 1.5em;
}

ol.breadcrumb {
    background: none;
    margin: 0 auto 20px;
    list-style: none;
    padding-left: 0;
}

    ol.breadcrumb > li {
        display: block;
    }
    ol.breadcrumb li:after {
        padding: 0 5px;
        color: #C0CCDA;
        content: "/ ";
    }
    ol.breadcrumb li:last-child:after, ol.breadcrumb > li+li:before { content: none; }

.text-center {
    text-align: center;
}

.float-left { float: left;}
.float-right { float: right; }

.height-100 { height: 100%; }

.margin-bottom-30 { margin-bottom: 30px; }

.display-table {
    display: table;
    width: 100%;
}
    .display-tableCell {
        display: table-cell;
    }

.fontSize-l, .button--l {
    font-size: 18px;
}
.verticalAlign-middle {
    vertical-align: middle;
}

.red-post-more {
    position: absolute;
    bottom: 20px;
    left: 20px;
    right: 20px;
}