<meta charset="utf-8"/>
<meta http-equiv="X-UA-Compatible" content="IE=edge,chrome=1"/>
<meta name="viewport" content="width=device-width, initial-scale=1, minimum-scale=1, user-scalable=no">

{% block head %}
<title>Redberry CMS - a Flask blog blueprint</title>
{% endblock %}

<link rel="amphtml" href="{{ request.url + '.amp' }}">

<link rel="stylesheet" href="https://maxcdn.bootstrapcdn.com/bootstrap/3.3.7/css/bootstrap.min.css" integrity="sha384-BVYiiSIFeK1dGmJRAkycuHAHRg32OmUcww7on3RYdg4Va+PmSTsz/K68vbdEjh4u" crossorigin="anonymous">
<link rel=stylesheet type=text/css href="{{ url_for('redberry.static', filename='css/redberry.css') }}">
<link rel=stylesheet type=text/css href="{{ url_for('static', filename='redberry/css/redberry.css') }}">
